==> estateplat-common-1.2.4-20210421.062911-727-sources.jar: cn/gtmap/estateplat/model/server/core/BdcJzq.java <==
package cn.gtmap.estateplat.model.server.core;

import java.util.Date;
import javax.persistence.Table;

@Table(name = "BDC_JZQ")
public class BdcJzq extends QllxParent implements QllxVo {
    private String zl;//坐落
    private String jzfw;//居住范围
    private String jztjhyq;//居住条件和要求
    private String fwsyqr;//房屋所有权人
    private String zxjzqywh;//注销居住权业务号
    private String zxjzqyy;//注销居住权原因
    private Date zxjzqdjsj;//注销居住权登记时间
    private String zxjzqdbr;//注销居住权登簿人
    private String djjg;//登记机构
    private String fj;//附记
    private String bz;//备注
    private String jzqhtbh;//居住权合同编号
    private Date jzqkssj;//居住权开始时间
    private Date jzqjssj;//居住权结束时间

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getJzfw() {
        return jzfw;
    }

    public void setJzfw(String jzfw) {
        this.jzfw = jzfw;
    }

    public String getJztjhyq() {
        return jztjhyq;
    }

    public void setJztjhyq(String jztjhyq) {
        this.jztjhyq = jztjhyq;
    }

    public String getFwsyqr() {
        return fwsyqr;
    }

    public void setFwsyqr(String fwsyqr) {
        this.fwsyqr = fwsyqr;
    }

    public String getZxjzqywh() {
        return zxjzqywh;
    }

    public void setZxjzqywh(String zxjzqywh) {
        this.zxjzqywh = zxjzqywh;
    }

    public String getZxjzqyy() {
        return zxjzqyy;
    }

    public void setZxjzqyy(String zxjzqyy) {
        this.zxjzqyy = zxjzqyy;
    }

    public Date getZxjzqdjsj() {
        return zxjzqdjsj;
    }

    public void setZxjzqdjsj(Date zxjzqdjsj) {
        this.zxjzqdjsj = zxjzqdjsj;
    }

    public String getZxjzqdbr() {
        return zxjzqdbr;
    }

    public void setZxjzqdbr(String zxjzqdbr) {
        this.zxjzqdbr = zxjzqdbr;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    @Override
    public String getFj() {
        return fj;
    }

    @Override
    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getJzqhtbh() {
        return jzqhtbh;
    }

    public void setJzqhtbh(String jzqhtbh) {
        this.jzqhtbh = jzqhtbh;
    }

    public Date getJzqkssj() {
        return jzqkssj;
    }

    public void setJzqkssj(Date jzqkssj) {
        this.jzqkssj = jzqkssj;
    }

    public Date getJzqjssj() {
        return jzqjssj;
    }

    public void setJzqjssj(Date jzqjssj) {
        this.jzqjssj = jzqjssj;
    }
}

==> estateplat-common-1.2.4-20210818.014413-845-sources.jar: cn/gtmap/estateplat/model/server/core/BdcJzq.java <==
package cn.gtmap.estateplat.model.server.core;

import java.util.Date;
import javax.persistence.Table;

@Table(name = "BDC_JZQ")
public class BdcJzq extends QllxParent implements QllxVo {
    private String zl;//坐落
    private String jzfw;//居住范围
    private String jztjhyq;//居住条件和要求
    private String fwsyqr;//房屋所有权人
    private String zxjzqywh;//注销居住权业务号
    private String zxjzqyy;//注销居住权原因
    private Date zxjzqdjsj;//注销居住权登记时间
    private String zxjzqdbr;//注销居住权登簿人
    private String djjg;//登记机构
    private String fj;//附记
    private String bz;//备注
    private String jzqhtbh;//居住权合同编号
    private Date jzqkssj;//居住权开始时间
    private Date jzqjssj;//居住权结束时间
    private Double fwmj;//房屋面积
    private Double tdmj;//土地面积


    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getJzfw() {
        return jzfw;
    }

    public void setJzfw(String jzfw) {
        this.jzfw = jzfw;
    }

    public String getJztjhyq() {
        return jztjhyq;
    }

    public void setJztjhyq(String jztjhyq) {
        this.jztjhyq = jztjhyq;
    }

    public String getFwsyqr() {
        return fwsyqr;
    }

    public void setFwsyqr(String fwsyqr) {
        this.fwsyqr = fwsyqr;
    }

    public String getZxjzqywh() {
        return zxjzqywh;
    }

    public void setZxjzqywh(String zxjzqywh) {
        this.zxjzqywh = zxjzqywh;
    }

    public String getZxjzqyy() {
        return zxjzqyy;
    }

    public void setZxjzqyy(String zxjzqyy) {
        this.zxjzqyy = zxjzqyy;
    }

    public Date getZxjzqdjsj() {
        return zxjzqdjsj;
    }

    public void setZxjzqdjsj(Date zxjzqdjsj) {
        this.zxjzqdjsj = zxjzqdjsj;
    }

    public String getZxjzqdbr() {
        return zxjzqdbr;
    }

    public void setZxjzqdbr(String zxjzqdbr) {
        this.zxjzqdbr = zxjzqdbr;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    @Override
    public String getFj() {
        return fj;
    }

    @Override
    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getJzqhtbh() {
        return jzqhtbh;
    }

    public void setJzqhtbh(String jzqhtbh) {
        this.jzqhtbh = jzqhtbh;
    }

    public Date getJzqkssj() {
        return jzqkssj;
    }

    public void setJzqkssj(Date jzqkssj) {
        this.jzqkssj = jzqkssj;
    }

    public Date getJzqjssj() {
        return jzqjssj;
    }

    public void setJzqjssj(Date jzqjssj) {
        this.jzqjssj = jzqjssj;
    }

    public Double getFwmj() {
        return fwmj;
    }

    public void setFwmj(Double fwmj) {
        this.fwmj = fwmj;
    }

    public Double getTdmj() {
        return tdmj;
    }

    public void setTdmj(Double tdmj) {
        this.tdmj = tdmj;
    }
}
